@@ -2,31 +2,16 @@ mod elements;
 mod literal;
 mod value;
 
-// used for ide hint
-#[cfg(debug_assertions)]
-mod remap {
-    pub use std::collections::btree_map::{Keys, Values};
-
-    pub type Set<V> = std::collections::BTreeSet<V>;
-    pub type Map<K, V> = std::collections::BTreeMap<K, V>;
-}
-
-#[cfg(not(debug_assertions))]
-mod remap {
-    pub use indexmap::map::{Keys, Values};
-
-    pub type Set<V> = indexmap::IndexSet<V>;
-    pub type Map<K, V> = indexmap::IndexMap<K, V>;
-}
-
-use self::remap::{Map, Set};
 pub use self::{
     elements::*,
     literal::Literal,
-    value::{Value, ValueType},
+    value::{Array, Object, Set, Value, ValueType},
 };
+pub use indexmap::map::{Keys, Values};
+use indexmap::{map::IndexMap, set::IndexSet};
 use num::{BigInt, BigUint};
 use std::{
+    collections::BTreeMap,
     fmt::{self, Debug, Display, Formatter},
     hash::{Hash, Hasher},
     mem::transmute,
